package esmith::AD::OU;

use strict;
use base 'esmith::AD';
no warnings ('qw');

=head1 NAME

esmith::AD::OU - Sub-Class to the Koozali esmith::AD API

=head1 SYNOPSIS

    use esmith::AD::OU;
   
    my $ad = esmith::AD::OU->new();
    my @organizational_units = $ad->OUs;
 
=head1 DESCRIPTION

This module provide esmith::AD::OU methods for management of organizational
units stored in the Koozali SME Server Active Directory.  These methods are 
the preferred methods to interact with user objects in the Active Directory.  
Many methods in this class inherit functionality from the esmith::AD parent 
class and provide run-time binding of LDAP query elements to these parent 
methods. Methods provided in this module abstract Net::LDAP so that knowledge 
of this module is not required.
=cut

sub new {
    my ($class, %params) = @_;
    
    #Define runtime LDAP query parameters
    my $base = {
                'default' => '&(objectClass=ou)(!(objectClass=computer))'
               };
    my $set  = {
                'all'     => '',
                'builtin' => '(!(objectClass=posixAccount))',
                'koozali' => '(objectClass=posixAccount)',
                'single'  => ''
               };
    my $type = {
                 'posix'   =>  ['top','ou','posixAccount']
               };

    my $attribute = {
                      'default' => 'sAMAccountName'
                    };
    my $self = {
                'base'      => $base,
                'set'       => $set,
                'attribute' => $attribute,
                'type'      => $type
               };

    
    #bless paramters into the class
    bless ($self, $class);

    return ($self);
}


=head2 Methods

Methods here
    
=head1 COPYRIGHT

Copyright (c) 2016 Koozali Foundation, Inc.
This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

=head1 AUTHOR

Greg Zartman, Koozali Foundation <gzartman@koozali.org>

=head1 SEE ALSO

Net::LDAP

=cut

1;
